@@ -233,8 +233,8 @@ class FITSFigure(Layers, Regions, Deprecated):
             if wcs.naxis != 2:
                 raise ValueError("FITSFigure initialization via WCS objects can only be done with 2-dimensional WCS objects")
             header = wcs.to_header()
-            header.update('NAXIS1', wcs.naxis1)
-            header.update('NAXIS2', wcs.naxis2)
+            header['NAXIS1'] = wcs.naxis1
+            header['NAXIS2'] = wcs.naxis2
             nx = header['NAXIS%i' % (dimensions[0] + 1)]
             ny = header['NAXIS%i' % (dimensions[1] + 1)]
             self._data = np.zeros((ny, nx), dtype=float)
