@@ -8,6 +8,9 @@ from mpl_toolkits.axes_grid.anchored_artists \
 import numpy as np
 from matplotlib.patches import FancyArrowPatch
 from matplotlib.font_manager import FontProperties
+from astropy import units as u
+
+from astropy.extern import six
 
 from . import wcs_util
 from .decorators import auto_refresh
@@ -113,7 +116,7 @@ class Compass(object):
 
         len_pix = length * (ymax - ymin)
 
-        degrees_per_pixel = wcs_util.degperpix(self._wcs)
+        degrees_per_pixel = wcs_util.celestial_pixel_scale(self._wcs)
 
         len_deg = len_pix * degrees_per_pixel
 
@@ -167,8 +170,8 @@ class Scalebar(object):
         Parameters
         ----------
 
-        length : float
-            The length of the scalebar
+        length : float, or quantity
+            The length of the scalebar in degrees, an angular quantity, or angular unit
 
         label : str, optional
             Label to place below the scalebar
@@ -194,7 +197,12 @@ class Scalebar(object):
         self._base_settings['borderpad'] = borderpad
         self._base_settings['pad'] = pad
 
-        degrees_per_pixel = wcs_util.degperpix(self._wcs)
+        if isinstance(length, u.Quantity):
+            length = length.to(u.degree).value
+        elif isinstance(length, u.Unit):
+            length = length.to(u.degree)
+
+        degrees_per_pixel = wcs_util.celestial_pixel_scale(self._wcs)
 
         length = length / degrees_per_pixel
 
@@ -203,7 +211,7 @@ class Scalebar(object):
         except:
             pass
 
-        if isinstance(corner, basestring):
+        if isinstance(corner, six.string_types):
             corner = corners[corner]
 
         self._scalebar = AnchoredSizeBar(self._ax.transData, length, label, corner, \
@@ -447,15 +455,17 @@ class Beam(object):
         Parameters
         ----------
 
-        major : float, optional
-            Major axis of the beam in degrees (overrides BMAJ if present)
+        major : float, quantity or unit, optional
+            Major axis of the beam in degrees or an angular quantity (overrides
+            BMAJ if present)
 
-        minor : float, optional
-            Minor axis of the beam in degrees (overrides BMIN if present)
+        minor : float, quantity or unit, optional
+            Minor axis of the beam in degrees or an angular quantity (overrides
+            BMIN if present)
 
-        angle : float, optional
-            Position angle of the beam on the sky in degrees (overrides
-            BPA if present) in the anticlockwise direction.
+        angle : float, quantity or unit, optional
+            Position angle of the beam on the sky in degrees or an angular
+            quantity (overrides BPA if present) in the anticlockwise direction.
 
         corner : int, optional
             The beam location. Acceptable values are 'left', 'right',
@@ -470,16 +480,31 @@ class Beam(object):
             See the matplotlib documentation for more details.
         '''
 
-        if isinstance(major, basestring):
+        if isinstance(major, six.string_types):
             major = self._header[major]
 
-        if isinstance(minor, basestring):
+        if isinstance(minor, six.string_types):
             minor = self._header[minor]
 
-        if isinstance(angle, basestring):
+        if isinstance(angle, six.string_types):
             angle = self._header[angle]
 
-        degrees_per_pixel = wcs_util.degperpix(self._wcs)
+        if isinstance(major, u.Quantity):
+            major = major.to(u.degree).value
+        elif isinstance(major, u.Unit):
+            major = major.to(u.degree)
+
+        if isinstance(minor, u.Quantity):
+            minor = minor.to(u.degree).value
+        elif isinstance(minor, u.Unit):
+            minor = minor.to(u.degree)
+
+        if isinstance(angle, u.Quantity):
+            angle = angle.to(u.degree).value
+        elif isinstance(angle, u.Unit):
+            angle = angle.to(u.degree)
+
+        degrees_per_pixel = wcs_util.celestial_pixel_scale(self._wcs)
 
         self._base_settings['minor'] = minor
         self._base_settings['major'] = major
@@ -497,7 +522,7 @@ class Beam(object):
         except:
             pass
 
-        if isinstance(corner, basestring):
+        if isinstance(corner, six.string_types):
             corner = corners[corner]
 
         self._beam = AnchoredEllipse(self._ax.transData, \
